@@ -24,7 +24,7 @@ __all__ = [
     "run_default_task",
 ]
 
-__version__ = "1.1.5"
+__version__ = "1.1.6"
 
 _DEFAULT_STDERR_LOGS = ["metamake.filesystem", "metamake.shell"]
 _all_tasks = {}
@@ -194,10 +194,11 @@ def metamake_bin():
     try:
         makefile_path = os.path.join(os.path.abspath(os.getcwd()), "Makefile.py")
         imp.load_module("Makefile", open(makefile_path, "r"), makefile_path, ('.py', 'U', 1))
-    except ImportError, e:
+
+    except (IOError, ImportError), e:
         
         errmsg = str(e)
-        if "Makefile" in errmsg:
+        if "Makefile" in errmsg or "No such file or directory" in errmsg:
             # this was probably unable to find Makefile.py
             print >> sys.stderr, "*** Makefile.py could not be loaded.  It appears that you have not defined one."
         else:
