@@ -7,10 +7,10 @@ def namespace(method=None):
     
     def decorate(method):
         global _current_namespace
-        old_namespace = _current_namespace
+        old_namespace = list(_current_namespace)
         _current_namespace += [method]
 
-        # define all the tasks
+        # define all the subtasks
         method()
 
         _current_namespace = old_namespace
