@@ -28,7 +28,15 @@ Date:    9 Mar 2007
 #   - Perhaps support arguments to touch().
 
 from logging import getLogger
-import sys, warnings, os, fnmatch, glob, shutil, codecs, md5
+import sys, warnings, os, fnmatch, glob, shutil, codecs
+try:
+    import hashlib
+    # quick backwards-compat with md5 module
+    class md5(object):
+        new = hashlib.md5
+
+except ImportError:
+    import md5
 
 __version__ = '2.2'
 __all__ = ['path', 'loggable_path']
