@@ -24,14 +24,14 @@ class FlagTestCase(TestCase):
         _reset_flag_parser()
     
     def test_boolean_flag_detects_true_value(self):
-        for value in ["true", "t", "1", "y", "yes", "on"]:
+        for value in ["True", "T", "TRUE", "true", "t", "1", "y", "yes", "on"]:
             _reset_flag_parser()
             _add_flag("boolean_flag=%s" % value)
             f = Flag("boolean_flag").explain("blah", convert=bool)
             self.assertEqual(f.value, True)
     
     def test_boolean_flag_detects_false_value(self):
-        for value in ["false", "f", "0", "n", "no", "off"]:
+        for value in ["False", "F", "FALSE", "false", "f", "0", "n", "no", "off"]:
             _reset_flag_parser()
             _add_flag("boolean_flag=%s" % value)
             f = Flag("boolean_flag").explain("blah", convert=bool)
